import { Query } from '@kevisual/query';
import type { Result } from '@kevisual/query/query';
type QueryConfigOpts = {
  query?: Query;
};
export type Config<T = any> = {
  id?: string;
  title?: string;
  key?: string;
  description?: string;
  data?: T;
  createdAt?: string;
  updatedAt?: string;
};
export type UploadConfig = {
  key?: string;
  version?: string;
};
export class QueryConfig {
  query: Query;
  constructor(opts?: QueryConfigOpts) {
    this.query = opts?.query || new Query();
  }
  async post<T = Config>(data: any) {
    return this.query.post<T>({ path: 'config', ...data });
  }
  async getConfig({ id, key }: { id?: string; key?: string }) {
    return this.post({
      key: 'get',
      data: {
        id,
        key,
      },
    });
  }
  async updateConfig(data: Config) {
    return this.post({
      key: 'update',
      data,
    });
  }
  async deleteConfig(id: string) {
    return this.post({
      key: 'delete',
      data: { id },
    });
  }
  async listConfig() {
    return this.post<{ list: Config[] }>({
      key: 'list',
    });
  }
  /**
   * 获取上传配置
   * @returns
   */
  async getUploadConfig() {
    return this.post<Result<Config<UploadConfig>>>({
      key: 'getUploadConfig',
    });
  }
  /**
   * 更新上传配置
   * @param data
   * @returns
   */
  async updateUploadConfig(data: Config) {
    return this.post<Result<Config<UploadConfig>>>({
      key: 'updateUploadConfig',
      data,
    });
  }
}

/**
 * 会员配置, 获取 admin 账户的配置项
 *
 */
export class VipQueryConfig extends QueryConfig {
  constructor(opts?: QueryConfigOpts) {
    super(opts);
  }
  /**
   * 获取会员配置, 是否开启会员，会员等级配置。
   * 请求数量配置
   * 资源上传配置
   *
   * @returns
   */
  async getVipConfig() {
    return this.post<Result<Config<UploadConfig>>>({
      key: 'shareConfig',
      data: {
        type: 'vip',
        username: 'admin',
      },
    });
  }
}
